Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(420)

Unified Diff: content/browser/bluetooth/bluetooth_allowed_devices_map.cc

Issue 2716583003: Rename Origin.unique() to opaque().
Patch Set: Update new uses post-rebase Created 3 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/bluetooth/bluetooth_allowed_devices_map.cc
diff --git a/content/browser/bluetooth/bluetooth_allowed_devices_map.cc b/content/browser/bluetooth/bluetooth_allowed_devices_map.cc
index 4b4ce9a95a924f5beac62de519fcdc84a16b4ee8..7704af56babe5fa4386f8ce266e5ef0b0fceb7e8 100644
--- a/content/browser/bluetooth/bluetooth_allowed_devices_map.cc
+++ b/content/browser/bluetooth/bluetooth_allowed_devices_map.cc
@@ -17,9 +17,9 @@ BluetoothAllowedDevicesMap::~BluetoothAllowedDevicesMap() {}
content::BluetoothAllowedDevices&
BluetoothAllowedDevicesMap::GetOrCreateAllowedDevices(
const url::Origin& origin) {
// "Unique" Origins generate the same key in maps, therefore are not
// supported.
- CHECK(!origin.unique());
+ CHECK(!origin.opaque());
auto iter = origin_to_allowed_devices_map_.find(origin);
if (iter == origin_to_allowed_devices_map_.end()) {
iter = origin_to_allowed_devices_map_.insert(
@@ -17,9 +17,9 @@ BluetoothAllowedDevicesMap::~BluetoothAllowedDevicesMap() {}
BluetoothAllowedDevicesMap::GetOrCreateAllowedDevices(
const url::Origin& origin) {
- // "Unique" Origins generate the same key in maps, therefore are not
+ // Opaque origins generate the same key in maps, therefore are not
// supported.

Powered by Google App Engine
This is Rietveld 408576698